# CHANGELOG



## v0.1.0 (2023-10-06)

### Feature

* feat: save hyperparameters in checkpoints ([`add3320`](https://github.com/KennethEnevoldsen/snp-transformer/commit/add332045f76eba33396db51ed7810a4bc565e24))

### Fix

* fix: fixed erorrs raised from test ([`c14ae16`](https://github.com/KennethEnevoldsen/snp-transformer/commit/c14ae163cbf82f7edef4299afc8b2bce61b98927))

* fix: minor fixes ([`c551612`](https://github.com/KennethEnevoldsen/snp-transformer/commit/c551612caf4c91d91b130b63b0b7064d2de04663))

### Style

* style: linting ([`ef3b320`](https://github.com/KennethEnevoldsen/snp-transformer/commit/ef3b3209df43ae5d54bb3a87c631751d459416cb))

* style: linting ([`e0f6f3d`](https://github.com/KennethEnevoldsen/snp-transformer/commit/e0f6f3db882ef2c149bc3cb9f37da618caab9987))

* style: linting ([`c0dbd39`](https://github.com/KennethEnevoldsen/snp-transformer/commit/c0dbd3937fbff0ce97e8efb4e48663656e386230))

### Unknown

* Merge pull request #11 from KennethEnevoldsen/add-mlm-accuracy

Add MLM accuracy ([`35b8eb6`](https://github.com/KennethEnevoldsen/snp-transformer/commit/35b8eb626bb76a98b76b41cbbc3764d712e49200))

* Merge pull request #10 from MartinBernstorff/main

feat: save hyperparameters in checkpoints ([`14983d5`](https://github.com/KennethEnevoldsen/snp-transformer/commit/14983d580bf7567fdd962641e2b454f404e42ff8))

* Merge branch &#39;add-mlm-accuracy&#39; of https://github.com/KennethEnevoldsen/snp-transformer into add-mlm-accuracy ([`006c71e`](https://github.com/KennethEnevoldsen/snp-transformer/commit/006c71e368f89459d9e062c9bedb27c56bd5147a))

* moved mlm acc into function ([`7ed7247`](https://github.com/KennethEnevoldsen/snp-transformer/commit/7ed7247de9d4d4444caeb1a9fbdc5ebcf67f6496))

* remove accidental copy paste ([`9bd452c`](https://github.com/KennethEnevoldsen/snp-transformer/commit/9bd452c8c7e25115a000e2014864fe7825fac6ef))

* 0.0.6
Automatically generated by python-semantic-release ([`de54d40`](https://github.com/KennethEnevoldsen/snp-transformer/commit/de54d405cbeefd4c2d7e810e18bacb0bba00a5fc))


## v0.0.6 (2023-09-26)

### Ci

* ci: removed windows support ([`3be156f`](https://github.com/KennethEnevoldsen/snp-transformer/commit/3be156f2009aa3794631809af0248b016fc87c5d))

### Fix

* fix: remove static path in config ([`31dc374`](https://github.com/KennethEnevoldsen/snp-transformer/commit/31dc3742e823ebf724f5d398c9fc15ff3883989c))

* fix: updated error message ([`5ebd81a`](https://github.com/KennethEnevoldsen/snp-transformer/commit/5ebd81a8f29afab7cf008e5234bcc306154db11d))

* fix: added missing dependency ([`d44edd0`](https://github.com/KennethEnevoldsen/snp-transformer/commit/d44edd0c1a8ab7e5b5841fbad32720ce5311bfac))

* fix: Updated configs ([`ac467b3`](https://github.com/KennethEnevoldsen/snp-transformer/commit/ac467b3dc7629c217085f9d2df821d8c90ca76d4))

* fix: tests ([`5081a3e`](https://github.com/KennethEnevoldsen/snp-transformer/commit/5081a3e24f9300e143b149668241a0402649a985))

* fix: ensure that logging works as intended ([`3f51073`](https://github.com/KennethEnevoldsen/snp-transformer/commit/3f5107309e12695a334467776f5ebcafa24ce000))

### Unknown

* ran ruff ([`23f0198`](https://github.com/KennethEnevoldsen/snp-transformer/commit/23f01981b3a727db0fdfd11b1f90a96291e55e40))

* Merge branch &#39;main&#39; of https://github.com/KennethEnevoldsen/snp-transformer ([`b69f98c`](https://github.com/KennethEnevoldsen/snp-transformer/commit/b69f98c9daad22fe828b0b79b7cab9c25a56ea15))

* minor ([`fd66009`](https://github.com/KennethEnevoldsen/snp-transformer/commit/fd66009481180afbe3697aa51e29437482fc2238))

* restructured repo ([`c9a32d1`](https://github.com/KennethEnevoldsen/snp-transformer/commit/c9a32d127c47f3b8bb63164c7dca4568aea6f3d9))

* added training config ([`136fa40`](https://github.com/KennethEnevoldsen/snp-transformer/commit/136fa4077d0bd837eb7a3b9bc0378fba41ac2440))

* added keynote presentation ([`272d7be`](https://github.com/KennethEnevoldsen/snp-transformer/commit/272d7be368adbcfdaca92504dfe472cf1207e055))


## v0.0.5 (2023-09-19)

### Fix

* fix: Added working model ([`41fe4c9`](https://github.com/KennethEnevoldsen/snp-transformer/commit/41fe4c91ed43e9256f663a916f9c7f2c2687036a))

### Unknown

* Merge branch &#39;main&#39; of https://github.com/KennethEnevoldsen/snp-transformer ([`4242b31`](https://github.com/KennethEnevoldsen/snp-transformer/commit/4242b317c66383cc9598e4f320acd5e778ac33de))

* Changed task modules to ligthning ([`2065cb3`](https://github.com/KennethEnevoldsen/snp-transformer/commit/2065cb39e3e7474d68bbe3c083eaafa838a44cd0))


## v0.0.4 (2023-08-29)

### Fix

* fix: refactor ([`1b47546`](https://github.com/KennethEnevoldsen/snp-transformer/commit/1b475460d3a4af13311c9c886c3f9eb7bacbed32))

* fix: Added working test for the embedding module ([`d568eee`](https://github.com/KennethEnevoldsen/snp-transformer/commit/d568eee82937701412c3ef83b5578e14b454ff49))

* fix: added embedding module ([`b6bbb22`](https://github.com/KennethEnevoldsen/snp-transformer/commit/b6bbb22d1f7b6bad32067121551bd3b4b5c312b0))

### Unknown

* Merge branch &#39;main&#39; of https://github.com/KennethEnevoldsen/snp-transformer ([`bed0bc7`](https://github.com/KennethEnevoldsen/snp-transformer/commit/bed0bc7813cfc38f02f5ecf6a4bc24c5b7e57a68))

* Merge branch &#39;main&#39; into add-embedding-module ([`203beb9`](https://github.com/KennethEnevoldsen/snp-transformer/commit/203beb9fb9dd41df28db3d46aa9dad8c95ad78b8))


## v0.0.3 (2023-08-29)

### Chore

* chore: remove unused test ([`0c45166`](https://github.com/KennethEnevoldsen/snp-transformer/commit/0c45166608e568ad629ac459ff3af3872047a658))

### Ci

* ci: fixed tox + static type checking ([`3ae7413`](https://github.com/KennethEnevoldsen/snp-transformer/commit/3ae74130ef603c02007b4afaeb7292d586814356))

* ci: change test to &gt;3.10 ([`c03760b`](https://github.com/KennethEnevoldsen/snp-transformer/commit/c03760b3b3708da0f5887c4e47e785d035d99f30))

* ci: fix dependencies ([`0f5fbe9`](https://github.com/KennethEnevoldsen/snp-transformer/commit/0f5fbe9146f055abe79c2119953b4356050257e2))

* ci: fix syntax error ([`2b37d45`](https://github.com/KennethEnevoldsen/snp-transformer/commit/2b37d452b50b58811a17c048b5701ac2fa6306b3))

* ci: Add token to static type check ([`f48fef6`](https://github.com/KennethEnevoldsen/snp-transformer/commit/f48fef694f7a8b566fafd14cb51e2e2c417fbc1d))

### Documentation

* docs: minimal updated to docs ([`05eb82c`](https://github.com/KennethEnevoldsen/snp-transformer/commit/05eb82c609e6c41215292fe55281b9a73c263578))

* docs: fixed badges ([`478ddb1`](https://github.com/KennethEnevoldsen/snp-transformer/commit/478ddb158ee53acaa2725e1d0ee5a40f98a84a19))

### Fix

* fix: ran pre-commit hooks ([`b6b7dc5`](https://github.com/KennethEnevoldsen/snp-transformer/commit/b6b7dc5f8c91af77adba3d1e32ee32a4128f8f3a))

* fix: Got a working dataset along with data structures ([`e4df237`](https://github.com/KennethEnevoldsen/snp-transformer/commit/e4df2374ab017b1d4f76475a13ff770d2576d214))

* fix: cruft update ([`d1cb893`](https://github.com/KennethEnevoldsen/snp-transformer/commit/d1cb8936827867497bac5f5ede66ffe00900b320))

### Unknown

* tests: Updated test to use conftest ([`f028a7c`](https://github.com/KennethEnevoldsen/snp-transformer/commit/f028a7ce3c8b7be4f7b596de5a61e61c3967fa8a))

* Merge branch &#39;add-data-structures&#39; ([`8396b6e`](https://github.com/KennethEnevoldsen/snp-transformer/commit/8396b6ed763474a673f77b27a8f1eece3277f0f6))

* Merge pull request #3 from KennethEnevoldsen/paper_outline

Added paper outline ([`0f9dcc3`](https://github.com/KennethEnevoldsen/snp-transformer/commit/0f9dcc392828c9adb2a783ccf367fc9a616d385b))

* paper: Updated based on comments from @dougspeed ([`826bdfc`](https://github.com/KennethEnevoldsen/snp-transformer/commit/826bdfc1471c43e528d0111393fc9ddfd952f4a8))

* initial data structures ([`693232c`](https://github.com/KennethEnevoldsen/snp-transformer/commit/693232ce731f23d1e168caee3756d4c0cabd876c))

* Merge branch &#39;main&#39; of https://github.com/KennethEnevoldsen/snp-transformer ([`3de7a88`](https://github.com/KennethEnevoldsen/snp-transformer/commit/3de7a8825aaa7fb90caa103e14fa7e1a050ffb2f))

* fixed static type check ([`351384c`](https://github.com/KennethEnevoldsen/snp-transformer/commit/351384c37f3d7134b3dd05cf63408f665fcde281))


## v0.0.2 (2023-08-13)

### Fix

* fix: Added some initial structure to the project ([`195bfc9`](https://github.com/KennethEnevoldsen/snp-transformer/commit/195bfc99b8e27c56f5489fa3588664522fe0ffc1))

### Unknown

* Merge branch &#39;main&#39; of https://github.com/KennethEnevoldsen/snp-transformer ([`76c3580`](https://github.com/KennethEnevoldsen/snp-transformer/commit/76c3580c49b944d0a4d0ae5e036d43a911d8bb2a))


## v0.0.1 (2023-08-13)

### Build

* build: Added torch as a dependency ([`df8d64b`](https://github.com/KennethEnevoldsen/snp-transformer/commit/df8d64bfa8bdd6d49bf130f69920ba026b26bac0))

### Chore

* chore: remove boilerplate files ([`232adb9`](https://github.com/KennethEnevoldsen/snp-transformer/commit/232adb953299b9d3849043891ec38dc117fc283f))

### Ci

* ci: removed docs workflow ([`b8d0560`](https://github.com/KennethEnevoldsen/snp-transformer/commit/b8d0560809e22c33d16575092cc56debcd733aca))

### Documentation

* docs: added paper outline ([`a0de7e6`](https://github.com/KennethEnevoldsen/snp-transformer/commit/a0de7e654db886bfe9a0b4d195adef7beaf52719))

* docs: updated docs ([`69a4222`](https://github.com/KennethEnevoldsen/snp-transformer/commit/69a42220e40db6a87f50f5b6cf9ef8027393a4d3))

### Fix

* fix: updated cruft ([`42d00d5`](https://github.com/KennethEnevoldsen/snp-transformer/commit/42d00d502acb2a76f549d00f50f47d76c20fa3f1))

### Unknown

* Merge branch &#39;main&#39; of https://github.com/KennethEnevoldsen/snp-transformer ([`cae9773`](https://github.com/KennethEnevoldsen/snp-transformer/commit/cae9773f7c55e5f9b1767e930fba7e57b4102c03))

* Merge pull request #2 from KennethEnevoldsen/dependabot/pip/invoke-2.2.0

deps:(deps-dev): bump invoke from 2.1.1 to 2.2.0 ([`2e8388f`](https://github.com/KennethEnevoldsen/snp-transformer/commit/2e8388f15f792b74a0867f2c20baac50d98e9b4e))

* Merge pull request #1 from KennethEnevoldsen/dependabot/pip/pyright-1.1.320

deps:(deps-dev): bump pyright from 1.1.305 to 1.1.320 ([`9e5421b`](https://github.com/KennethEnevoldsen/snp-transformer/commit/9e5421b181adeff52ca7a526dd3a7bb1d24c724b))

* deps:(deps-dev): bump invoke from 2.1.1 to 2.2.0

Bumps [invoke](https://github.com/pyinvoke/invoke) from 2.1.1 to 2.2.0.
- [Commits](https://github.com/pyinvoke/invoke/compare/2.1.1...2.2.0)

---
updated-dependencies:
- dependency-name: invoke
  dependency-type: direct:production
  update-type: version-update:semver-minor
...

Signed-off-by: dependabot[bot] &lt;support@github.com&gt; ([`068e048`](https://github.com/KennethEnevoldsen/snp-transformer/commit/068e048847091decb4255dbd3ba2bfb96cefa4ea))

* deps:(deps-dev): bump pyright from 1.1.305 to 1.1.320

Bumps [pyright](https://github.com/RobertCraigie/pyright-python) from 1.1.305 to 1.1.320.
- [Release notes](https://github.com/RobertCraigie/pyright-python/releases)
- [Commits](https://github.com/RobertCraigie/pyright-python/compare/v1.1.305...v1.1.320)

---
updated-dependencies:
- dependency-name: pyright
  dependency-type: direct:production
  update-type: version-update:semver-patch
...

Signed-off-by: dependabot[bot] &lt;support@github.com&gt; ([`6497fa5`](https://github.com/KennethEnevoldsen/snp-transformer/commit/6497fa5b5c281105e58ec1eac529178c1de465d5))

* updated readme ([`0adad5a`](https://github.com/KennethEnevoldsen/snp-transformer/commit/0adad5a0162d5ea79a3c946023c4feb6aebd8229))

* updated readme ([`19033f0`](https://github.com/KennethEnevoldsen/snp-transformer/commit/19033f0ff8d1ccc317996549a2e3ea67f7f5c3cb))

* initial commit ([`9c5d964`](https://github.com/KennethEnevoldsen/snp-transformer/commit/9c5d964b70a04e05cb035a3479a2441e3691ea02))
